@@ -1,7 +1,7 @@
 ;; -*- mode: sxml-ui; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2023 - 2024
+;;;; Copyright (C) 2023 - 2026
 ;;;; Free Software Foundation, Inc.
 
 ;;;; This file is part of GNU G-Golf
@@ -35,12 +35,20 @@
        (item
          (attribute (@ (name "label")
                        (translatable "yes")) _Inspector)
-         (attribute (@ (name "action")) app.inspector)))
+         (attribute (@ (name "action")) app.inspector))
+       (item
+         (attribute (@ (name "label")
+                       (translatable "yes")) "A_daptive Preview")
+         (attribute (@ (name "action")) window.adaptive-preview)))
      (section
        (item
          (attribute (@ (name "label")
                        (translatable "yes")) _Preferences)
          (attribute (@ (name "action")) app.preferences))
+       (item
+         (attribute (@ (name "label")
+                       (translatable "yes")) "_Keyboard Shortcuts")
+         (attribute (@ (name "action")) app.shortcuts))
        (item
          (attribute (@ (name "label")
                        (translatable "yes")) _"About Adwaita Demo")
@@ -190,6 +198,20 @@
      (property (@ (name "child"))
        (object (@ (class "AdwDemoPageSpinner"))))))
 
+(define %toggle-groups-page
+  '(object (@ (class "GtkStackPage"))
+     (property (@ (name "title")
+                  (translatable "yes")) "Toggle Groups")
+     (property (@ (name "child"))
+       (object (@ (class "AdwDemoPageToggleGroups"))))))
+
+(define %wrap-box-page
+  '(object (@ (class "GtkStackPage"))
+     (property (@ (name "title")
+                  (translatable "yes")) "Wrap Box")
+     (property (@ (name "child"))
+       (object (@ (class "AdwDemoPageWrapBox"))))))
+
 (define %adw-demo-window-sidebar
   `(object (@ (class "AdwNavigationPage"))
      (property (@ (name "title")
@@ -244,7 +266,9 @@
          (child ,%banner-page)
          (child ,%bottom-sheets-page)
          (child ,%multi-layout-page)
-         (child ,%spinner-page)))))
+         (child ,%spinner-page)
+         (child ,%toggle-groups-page)
+         (child ,%wrap-box-page)))))
 
 (define %adw-demo-window
   `(interface
